==> qore-1.6.0.tar.bz2: qore-1.6.0/docs/modules/DataProvider/html/struct_data_provider_1_1_data_provider_info.js <==
var struct_data_provider_1_1_data_provider_info =
[
    [ "add_field_options", "struct_data_provider_1_1_data_provider_info.html#a0c360c36933d1349b1b25dc29256b1f3", null ],
    [ "child_create_options", "struct_data_provider_1_1_data_provider_info.html#a752a616529b0d85ede6e520f58dece8b", null ],
    [ "child_delete_options", "struct_data_provider_1_1_data_provider_info.html#a3e74c9131351257c1f9435b9c8e9965a", null ],
    [ "children", "struct_data_provider_1_1_data_provider_info.html#ab4c13f2df213c9cd99e90d2c5f1e5d40", null ],
    [ "constructor_options", "struct_data_provider_1_1_data_provider_info.html#a9b8578d70ed12ef55972c17d38f35410", null ],
    [ "create_options", "struct_data_provider_1_1_data_provider_info.html#a9e6e33aeb3955e61397c79287a6a7a5d", null ],
    [ "delete_field_options", "struct_data_provider_1_1_data_provider_info.html#ac07c145f3daaa8e7405b3710d9419df5", null ],
    [ "desc", "struct_data_provider_1_1_data_provider_info.html#adc3381f78eea899e4c7c9983fa654922", null ],
    [ "has_record", "struct_data_provider_1_1_data_provider_info.html#afb1c6af92a1a848733b5dcae214986c6", null ],
    [ "mapper_keys", "struct_data_provider_1_1_data_provider_info.html#a78d08fa3c961f677293318f2f482c1d7", null ],
    [ "name", "struct_data_provider_1_1_data_provider_info.html#a59faa103679df01e9e501de63472d39e", null ],
    [ "record_requires_search_options", "struct_data_provider_1_1_data_provider_info.html#a8664b380bead15fdb3582b8f7e0767dc", null ],
    [ "request_options", "struct_data_provider_1_1_data_provider_info.html#a4ef503043dde9ad5921fb1d31dc84f8d", null ],
    [ "search_options", "struct_data_provider_1_1_data_provider_info.html#a558497c0cbd189290573fc58142ec544", null ],
    [ "supports_add_field", "struct_data_provider_1_1_data_provider_info.html#a5d8320604f5f3de063c25ea673c6ccf4", null ],
    [ "supports_bulk_create", "struct_data_provider_1_1_data_provider_info.html#abfca9615ebec881841d9ee1127d041dc", null ],
    [ "supports_bulk_read", "struct_data_provider_1_1_data_provider_info.html#a0bc7b0b204e71d0304a7f7879cd8deb4", null ],
    [ "supports_bulk_upsert", "struct_data_provider_1_1_data_provider_info.html#a6d803adbbba3aebfc6e4ff21e7b96e92", null ],
    [ "supports_child_create", "struct_data_provider_1_1_data_provider_info.html#a3dba477d9171000010a710bad7ae6e92", null ],
    [ "supports_child_delete", "struct_data_provider_1_1_data_provider_info.html#a28cbf660bd62270fcdc7dd13c33d6aea", null ],
    [ "supports_children", "struct_data_provider_1_1_data_provider_info.html#ac2d3daf465ad7b27a78ffd57072ebb82", null ],
    [ "supports_create", "struct_data_provider_1_1_data_provider_info.html#aa861609325bdc140c3df5ade56f148cc", null ],
    [ "supports_delete", "struct_data_provider_1_1_data_provider_info.html#a03365ab8ee7965f0a04779a658a4fd45", null ],
    [ "supports_delete_field", "struct_data_provider_1_1_data_provider_info.html#a370e3e1f67e34256f4fc96d757012ae1", null ],
    [ "supports_native_search", "struct_data_provider_1_1_data_provider_info.html#a412061810da94fa2cb02b310cebc6cf9", null ],
    [ "supports_read", "struct_data_provider_1_1_data_provider_info.html#a82f69a9926a237125d3c12482647c404", null ],
    [ "supports_request", "struct_data_provider_1_1_data_provider_info.html#a92c8bec23b5baecd32d0a27c640859e1", null ],
    [ "supports_update", "struct_data_provider_1_1_data_provider_info.html#a8add15abae4ec692dea441ffafe189f7", null ],
    [ "supports_update_field", "struct_data_provider_1_1_data_provider_info.html#a9226d33657b357f745887d1eac834aed", null ],
    [ "supports_upsert", "struct_data_provider_1_1_data_provider_info.html#abecd5865cd94dbaed26069cc83a5fc09", null ],
    [ "transaction_management", "struct_data_provider_1_1_data_provider_info.html#a1b1ffae69aed98e0eda67328abebf4c0", null ],
    [ "type", "struct_data_provider_1_1_data_provider_info.html#a35b6587734a2c9d4b9e2a8b646a7b0b5", null ],
    [ "update_field_options", "struct_data_provider_1_1_data_provider_info.html#ace544d5dd078f6284495b6ffc10e4a32", null ],
    [ "upsert_options", "struct_data_provider_1_1_data_provider_info.html#a8e6077cefe43b0d267526774e62ee2d7", null ]
];

==> qore-1.7.1.tar.bz2: qore-1.7.1/docs/modules/DataProvider/html/struct_data_provider_1_1_data_provider_info.js <==
var struct_data_provider_1_1_data_provider_info =
[
    [ "add_field_options", "struct_data_provider_1_1_data_provider_info.html#a0c360c36933d1349b1b25dc29256b1f3", null ],
    [ "child_create_options", "struct_data_provider_1_1_data_provider_info.html#a752a616529b0d85ede6e520f58dece8b", null ],
    [ "child_delete_options", "struct_data_provider_1_1_data_provider_info.html#a3e74c9131351257c1f9435b9c8e9965a", null ],
    [ "children", "struct_data_provider_1_1_data_provider_info.html#ab4c13f2df213c9cd99e90d2c5f1e5d40", null ],
    [ "constructor_options", "struct_data_provider_1_1_data_provider_info.html#a9b8578d70ed12ef55972c17d38f35410", null ],
    [ "create_options", "struct_data_provider_1_1_data_provider_info.html#a9e6e33aeb3955e61397c79287a6a7a5d", null ],
    [ "delete_field_options", "struct_data_provider_1_1_data_provider_info.html#ac07c145f3daaa8e7405b3710d9419df5", null ],
    [ "desc", "struct_data_provider_1_1_data_provider_info.html#adc3381f78eea899e4c7c9983fa654922", null ],
    [ "has_record", "struct_data_provider_1_1_data_provider_info.html#afb1c6af92a1a848733b5dcae214986c6", null ],
    [ "mapper_keys", "struct_data_provider_1_1_data_provider_info.html#a78d08fa3c961f677293318f2f482c1d7", null ],
    [ "name", "struct_data_provider_1_1_data_provider_info.html#a59faa103679df01e9e501de63472d39e", null ],
    [ "record_requires_search_options", "struct_data_provider_1_1_data_provider_info.html#a8664b380bead15fdb3582b8f7e0767dc", null ],
    [ "request_options", "struct_data_provider_1_1_data_provider_info.html#a4ef503043dde9ad5921fb1d31dc84f8d", null ],
    [ "schema_type", "struct_data_provider_1_1_data_provider_info.html#af63cb50938a573bf4f4a4532ba3a9354", null ],
    [ "search_options", "struct_data_provider_1_1_data_provider_info.html#a558497c0cbd189290573fc58142ec544", null ],
    [ "supports_add_field", "struct_data_provider_1_1_data_provider_info.html#a5d8320604f5f3de063c25ea673c6ccf4", null ],
    [ "supports_bulk_create", "struct_data_provider_1_1_data_provider_info.html#abfca9615ebec881841d9ee1127d041dc", null ],
    [ "supports_bulk_read", "struct_data_provider_1_1_data_provider_info.html#a0bc7b0b204e71d0304a7f7879cd8deb4", null ],
    [ "supports_bulk_upsert", "struct_data_provider_1_1_data_provider_info.html#a6d803adbbba3aebfc6e4ff21e7b96e92", null ],
    [ "supports_child_create", "struct_data_provider_1_1_data_provider_info.html#a3dba477d9171000010a710bad7ae6e92", null ],
    [ "supports_child_delete", "struct_data_provider_1_1_data_provider_info.html#a28cbf660bd62270fcdc7dd13c33d6aea", null ],
    [ "supports_children", "struct_data_provider_1_1_data_provider_info.html#ac2d3daf465ad7b27a78ffd57072ebb82", null ],
    [ "supports_create", "struct_data_provider_1_1_data_provider_info.html#aa861609325bdc140c3df5ade56f148cc", null ],
    [ "supports_delete", "struct_data_provider_1_1_data_provider_info.html#a03365ab8ee7965f0a04779a658a4fd45", null ],
    [ "supports_delete_field", "struct_data_provider_1_1_data_provider_info.html#a370e3e1f67e34256f4fc96d757012ae1", null ],
    [ "supports_native_search", "struct_data_provider_1_1_data_provider_info.html#a412061810da94fa2cb02b310cebc6cf9", null ],
    [ "supports_read", "struct_data_provider_1_1_data_provider_info.html#a82f69a9926a237125d3c12482647c404", null ],
    [ "supports_request", "struct_data_provider_1_1_data_provider_info.html#a92c8bec23b5baecd32d0a27c640859e1", null ],
    [ "supports_schema", "struct_data_provider_1_1_data_provider_info.html#ae9a9bd29af4c27233fccaa9fc7d4b924", null ],
    [ "supports_update", "struct_data_provider_1_1_data_provider_info.html#a8add15abae4ec692dea441ffafe189f7", null ],
    [ "supports_update_field", "struct_data_provider_1_1_data_provider_info.html#a9226d33657b357f745887d1eac834aed", null ],
    [ "supports_upsert", "struct_data_provider_1_1_data_provider_info.html#abecd5865cd94dbaed26069cc83a5fc09", null ],
    [ "transaction_management", "struct_data_provider_1_1_data_provider_info.html#a1b1ffae69aed98e0eda67328abebf4c0", null ],
    [ "type", "struct_data_provider_1_1_data_provider_info.html#a35b6587734a2c9d4b9e2a8b646a7b0b5", null ],
    [ "update_field_options", "struct_data_provider_1_1_data_provider_info.html#ace544d5dd078f6284495b6ffc10e4a32", null ],
    [ "upsert_options", "struct_data_provider_1_1_data_provider_info.html#a8e6077cefe43b0d267526774e62ee2d7", null ]
];
